sqlobject.tests.test_exceptions module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_exceptions module

class `sqlobject.tests.test_exceptions.` `SOTestException`(**kw)

  Bases: `sqlobject.main.SQLObject`

  classmethod `byName`(val, connection=None)
  `j` = so_test_exception
  property `name`
  `q` = so_test_exception
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_exceptions.SOTestException`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_exception'

class `sqlobject.tests.test_exceptions.` `SOTestExceptionWithNonexistingTable`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_exception_with_nonexisting_table
  `q` = so_test_exception_with_nonexisting_table
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_exceptions.SOTestExceptionWithNonexistingTable`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_exception_with_nonexisting_table'

`sqlobject.tests.test_exceptions.` `test_exceptions`()